package com.ruoyi.gysl.controller;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.gysl.entity.Ml;
import com.ruoyi.gysl.service.MlService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

@Api(tags ="目录管理" )
@RestController
@RequestMapping("/gysl/Ml")
public class MlController extends BaseController {
    /**
     * 服务对象
     */
    @Resource
    private MlService mlService;

    /**
     * 分页查询目录数据
     *
     * @param ml 查询条件实体
     * @return 所有数据
     */

    @GetMapping("/list")
    @ApiOperation("分页查询目录数据")
    public TableDataInfo list(Ml ml) {
        startPage(); // 开启分页
        List<Ml> list = mlService.selectMl(ml);
        return getDataTable(list);
        // 封装分页结果
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("{id}")
    @ApiOperation("通过主键查询目录")
    public AjaxResult select(@PathVariable Integer id){
        return success(mlService.selectMlId(id));
    }

    /**
     * 新增数据
     *@param ml 实体对象
     * @return 新增结果
     */
    @PostMapping("/add")
    @ApiOperation("新增数据")
    public AjaxResult add(@RequestBody Ml ml) {
        return success(mlService.saveMl(ml));
    }

    /**
     * 修改数据
     *
     * @param ml 实体对象
     * @return 修改结果
     */
    @PostMapping("/edit")
    @ApiOperation("修改数据")
    public AjaxResult update(@RequestBody Ml ml) {
        return success(mlService.updateById(ml));
    }

    /**
     * 删除数据
     *
     * @param id 主键
     * @return 删除结果
     */
    @DeleteMapping("/delete/{id}")
    @ApiOperation("删除数据")
    public AjaxResult delete(@PathVariable Integer id) {
        return success(mlService.deleteMl(id));
    }
}
